// This file is generated by kconfig_compiler_kf6 from thumbnailaside.kcfg.
// All changes you do to this file will be lost.
#ifndef KWIN_THUMBNAILASIDECONFIG_H
#define KWIN_THUMBNAILASIDECONFIG_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

namespace KWin {

class ThumbnailAsideConfig : public KConfigSkeleton
{
  public:

    static ThumbnailAsideConfig *self();
    static void instance(const QString& cfgfilename);
    static void instance(KSharedConfig::Ptr config);
    ~ThumbnailAsideConfig() override;

    /**
      Set MaxWidth
    */
    static
    void setMaxWidth( int v )
    {
      if (!self()->isMaxWidthImmutable())
        self()->mMaxWidth = v;
    }

    /**
      Get MaxWidth
    */
    static
    int maxWidth()
    {
      return self()->mMaxWidth;
    }

    /**
      Is MaxWidth Immutable
    */
    static
    bool isMaxWidthImmutable()
    {
      return self()->isImmutable( QStringLiteral( "MaxWidth" ) );
    }

    /**
      Set Spacing
    */
    static
    void setSpacing( int v )
    {
      if (!self()->isSpacingImmutable())
        self()->mSpacing = v;
    }

    /**
      Get Spacing
    */
    static
    int spacing()
    {
      return self()->mSpacing;
    }

    /**
      Is Spacing Immutable
    */
    static
    bool isSpacingImmutable()
    {
      return self()->isImmutable( QStringLiteral( "Spacing" ) );
    }

    /**
      Set Opacity
    */
    static
    void setOpacity( double v )
    {
      if (!self()->isOpacityImmutable())
        self()->mOpacity = v;
    }

    /**
      Get Opacity
    */
    static
    double opacity()
    {
      return self()->mOpacity;
    }

    /**
      Is Opacity Immutable
    */
    static
    bool isOpacityImmutable()
    {
      return self()->isImmutable( QStringLiteral( "Opacity" ) );
    }

    /**
      Set Screen
    */
    static
    void setScreen( int v )
    {
      if (!self()->isScreenImmutable())
        self()->mScreen = v;
    }

    /**
      Get Screen
    */
    static
    int screen()
    {
      return self()->mScreen;
    }

    /**
      Is Screen Immutable
    */
    static
    bool isScreenImmutable()
    {
      return self()->isImmutable( QStringLiteral( "Screen" ) );
    }

  protected:
    ThumbnailAsideConfig(KSharedConfig::Ptr config);
    friend class ThumbnailAsideConfigHelper;


    // Effect-thumbnailaside
    int mMaxWidth;
    int mSpacing;
    double mOpacity;
    int mScreen;
};

}

#endif

