// This file is generated by kconfig_compiler_kf6 from nightlightstate.kcfg.
// All changes you do to this file will be lost.

#include "nightlightstate.h"

NightLightState::NightLightState( )
  : KConfigSkeleton( KSharedConfig::openStateConfig(QStringLiteral( "kwinstaterc") ) )
{
  setCurrentGroup( QStringLiteral( "NightLight" ) );

  KConfigSkeleton::ItemString  *itemState;
  itemState = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "State" ), mState );
  addItem( itemState, QStringLiteral( "State" ) );
}

NightLightState::~NightLightState()
{
}

