/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.KWin.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef KWINADAPTOR_H
#define KWINADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "dbusinterface.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.KWin
 */
class KWinAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.KWin")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.KWin\">\n"
"    <method name=\"reconfigure\">\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"killWindow\">\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"setCurrentDesktop\">\n"
"      <arg direction=\"in\" type=\"i\" name=\"desktop\"/>\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"currentDesktop\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"nextDesktop\"/>\n"
"    <method name=\"previousDesktop\"/>\n"
"    <signal name=\"reloadConfig\"/>\n"
"    <method name=\"supportInformation\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"activeOutputName\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"showDebugConsole\"/>\n"
"    <method name=\"replace\"/>\n"
"    <method name=\"queryWindowInfo\">\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"      <arg direction=\"out\" type=\"a{sv}\"/>\n"
"    </method>\n"
"    <method name=\"getWindowInfo\">\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"      <arg direction=\"out\" type=\"a{sv}\"/>\n"
"    </method>\n"
"    <property access=\"read\" type=\"b\" name=\"showingDesktop\"/>\n"
"    <method name=\"showDesktop\">\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"showing\"/>\n"
"    </method>\n"
"    <signal name=\"showingDesktopChanged\">\n"
"      <arg direction=\"out\" type=\"b\" name=\"showing\"/>\n"
"    </signal>\n"
"  </interface>\n"
        "")
public:
    KWinAdaptor(KWin::DBusInterface *parent);
    ~KWinAdaptor() override;

    inline KWin::DBusInterface *parent() const
    { return static_cast<KWin::DBusInterface *>(QObject::parent()); }

public: // PROPERTIES
    Q_PROPERTY(bool showingDesktop READ showingDesktop)
    bool showingDesktop() const;

public Q_SLOTS: // METHODS
    QString activeOutputName();
    int currentDesktop();
    QVariantMap getWindowInfo(const QString &in0);
    Q_NOREPLY void killWindow();
    void nextDesktop();
    void previousDesktop();
    QVariantMap queryWindowInfo();
    Q_NOREPLY void reconfigure();
    void replace();
    bool setCurrentDesktop(int desktop);
    void showDebugConsole();
    Q_NOREPLY void showDesktop(bool showing);
    QString supportInformation();
Q_SIGNALS: // SIGNALS
    void reloadConfig();
    void showingDesktopChanged(bool showing);
};

#endif
