// This file is generated by kconfig_compiler_kf6 from magiclamp.kcfg.
// All changes you do to this file will be lost.
#ifndef KWIN_MAGICLAMPCONFIG_H
#define KWIN_MAGICLAMPCONFIG_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

namespace KWin {

class MagicLampConfig : public KConfigSkeleton
{
  public:

    static MagicLampConfig *self();
    static void instance(const QString& cfgfilename);
    static void instance(KSharedConfig::Ptr config);
    ~MagicLampConfig() override;

    /**
      Set AnimationDuration
    */
    static
    void setAnimationDuration( int v )
    {
      if (!self()->isAnimationDurationImmutable())
        self()->mAnimationDuration = v;
    }

    /**
      Get AnimationDuration
    */
    static
    int animationDuration()
    {
      return self()->mAnimationDuration;
    }

    /**
      Is AnimationDuration Immutable
    */
    static
    bool isAnimationDurationImmutable()
    {
      return self()->isImmutable( QStringLiteral( "AnimationDuration" ) );
    }

  protected:
    MagicLampConfig(KSharedConfig::Ptr config);
    friend class MagicLampConfigHelper;


    // Effect-magiclamp
    int mAnimationDuration;
};

}

#endif

