// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#ifndef VIRTUALKEYBOARDDATA_H
#define VIRTUALKEYBOARDDATA_H

#include <QObject>

#include "kcmoduledata.h"



class VirtualKeyboardSettings;


class VirtualKeyboardData : public KCModuleData
{
    Q_OBJECT

public:
    explicit VirtualKeyboardData(QObject *parent = nullptr);
    VirtualKeyboardSettings *settings() const;


private:
    VirtualKeyboardSettings *m_settings;

};



#endif
