// This file is autogenerated. Changes will be overwritten.
#include "EWIEGA46WW/moc_a11ykeyboardmonitor.cpp"
#include "IKXJCJ3L24/moc_drm_commit_thread.cpp"
#include "TYIMJFNRJO/moc_color_manager.cpp"
#include "TAC5DWH4SE/moc_gpumanager.cpp"
#include "TAC5DWH4SE/moc_rect.cpp"
#include "TAC5DWH4SE/moc_renderdevice.cpp"
#include "EWIEGA46WW/moc_internalinputmethodcontext.cpp"
#include "EWIEGA46WW/moc_multigpuswapchain.cpp"
#include "QSLIUTEOWB/moc_rootitem.cpp"
#include "EWIEGA46WW/moc_useractionprompt.cpp"
#include "IEXH3JLKNG/moc_appmenu.cpp"
#include "IEXH3JLKNG/moc_backgroundeffect_v1.cpp"
#include "IEXH3JLKNG/moc_colorrepresentation_v1.cpp"
#include "IEXH3JLKNG/moc_cursorshape_v1.cpp"
#include "IEXH3JLKNG/moc_display_p.cpp"
#include "IEXH3JLKNG/moc_externalbrightness_v1.cpp"
#include "IEXH3JLKNG/moc_fifo_v1.cpp"
#include "IEXH3JLKNG/moc_fixes.cpp"
#include "IEXH3JLKNG/moc_linux_drm_syncobj_v1.cpp"
#include "IEXH3JLKNG/moc_pointerwarp_v1.cpp"
#include "IEXH3JLKNG/moc_presentationtime.cpp"
#include "IEXH3JLKNG/moc_securitycontext_v1.cpp"
#include "IEXH3JLKNG/moc_singlepixelbuffer.cpp"
#include "IEXH3JLKNG/moc_xdgdialog_v1.cpp"
#include "IEXH3JLKNG/moc_xdgsession_v1.cpp"
#include "IEXH3JLKNG/moc_xdgsystembell_v1.cpp"
#include "IEXH3JLKNG/moc_xdgtoplevelicon_v1.cpp"
#include "IEXH3JLKNG/moc_xdgtopleveltag_v1.cpp"
#include "EWIEGA46WW/moc_xxpipv1integration.cpp"
#include "EWIEGA46WW/moc_xxpipv1window.cpp"
