/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.KWin.Session.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "sessionadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class SessionAdaptor
 */

SessionAdaptor::SessionAdaptor(KWin::SessionManager *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

SessionAdaptor::~SessionAdaptor()
{
    // destructor
}

void SessionAdaptor::aboutToSaveSession(const QString &name)
{
    // handle method call org.kde.KWin.Session.aboutToSaveSession
    parent()->aboutToSaveSession(name);
}

bool SessionAdaptor::closeWaylandWindows()
{
    // handle method call org.kde.KWin.Session.closeWaylandWindows
    return parent()->closeWaylandWindows();
}

void SessionAdaptor::finishSaveSession(const QString &name)
{
    // handle method call org.kde.KWin.Session.finishSaveSession
    parent()->finishSaveSession(name);
}

void SessionAdaptor::loadSession(const QString &name)
{
    // handle method call org.kde.KWin.Session.loadSession
    parent()->loadSession(name);
}

void SessionAdaptor::quit()
{
    // handle method call org.kde.KWin.Session.quit
    parent()->quit();
}

void SessionAdaptor::setState(uint state)
{
    // handle method call org.kde.KWin.Session.setState
    parent()->setState(state);
}


#include "moc_sessionadaptor.cpp"
