// This file is generated by kconfig_compiler_kf6 from kwinswitcheffectsettings.kcfg.
// All changes you do to this file will be lost.

#include "kwinswitcheffectsettings.h"

using namespace KWin::TabBox;

SwitchEffectSettings::SwitchEffectSettings( const QString & EffectGroup, QObject *parent )
  : KConfigSkeleton( QStringLiteral( "kwinrc" ) )
  , mParamEffectGroup(EffectGroup)
{
  setParent(parent);
  setCurrentGroup( QStringLiteral( "%1" ).arg( mParamEffectGroup ) );

  KConfigSkeleton::ItemBool  *itemTabBox;
  itemTabBox = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "TabBox" ), mTabBox, false );
  addItem( itemTabBox, QStringLiteral( "TabBox" ) );
  KConfigSkeleton::ItemBool  *itemTabBoxAlternative;
  itemTabBoxAlternative = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "TabBoxAlternative" ), mTabBoxAlternative, false );
  addItem( itemTabBoxAlternative, QStringLiteral( "TabBoxAlternative" ) );
}

bool SwitchEffectSettings::defaultTabBoxValue_helper() const
{

  return false;
}

bool SwitchEffectSettings::defaultTabBoxAlternativeValue_helper() const
{

  return false;
}

SwitchEffectSettings::~SwitchEffectSettings()
{
}

