// This file is autogenerated by kcoreaddons_target_static_plugins, do not edit!
//clazy:excludeall=non-pod-global-static
#include <QPluginLoader>
extern void kRegisterStaticPluginFunction(const QString &, const QString &, QStaticPlugin);


extern const QT_PREPEND_NAMESPACE(QStaticPlugin) qt_static_plugin_blendchanges_factory();
class Staticblendchanges_factoryPluginInstance
{
public:
Staticblendchanges_factoryPluginInstance()
{
kRegisterStaticPluginFunction(
    QStringLiteral("blendchanges"),
    QStringLiteral("kwin/effects/plugins"),
    qt_static_plugin_blendchanges_factory()
);
}
};
static Staticblendchanges_factoryPluginInstance staticblendchanges_factoryInstance;

extern const QT_PREPEND_NAMESPACE(QStaticPlugin) qt_static_plugin_blur_factory();
class Staticblur_factoryPluginInstance
{
public:
Staticblur_factoryPluginInstance()
{
kRegisterStaticPluginFunction(
    QStringLiteral("blur"),
    QStringLiteral("kwin/effects/plugins"),
    qt_static_plugin_blur_factory()
);
}
};
static Staticblur_factoryPluginInstance staticblur_factoryInstance;

extern const QT_PREPEND_NAMESPACE(QStaticPlugin) qt_static_plugin_colorblindnesscorrection_factory();
class Staticcolorblindnesscorrection_factoryPluginInstance
{
public:
Staticcolorblindnesscorrection_factoryPluginInstance()
{
kRegisterStaticPluginFunction(
    QStringLiteral("colorblindnesscorrection"),
    QStringLiteral("kwin/effects/plugins"),
    qt_static_plugin_colorblindnesscorrection_factory()
);
}
};
static Staticcolorblindnesscorrection_factoryPluginInstance staticcolorblindnesscorrection_factoryInstance;

extern const QT_PREPEND_NAMESPACE(QStaticPlugin) qt_static_plugin_colorpicker_factory();
class Staticcolorpicker_factoryPluginInstance
{
public:
Staticcolorpicker_factoryPluginInstance()
{
kRegisterStaticPluginFunction(
    QStringLiteral("colorpicker"),
    QStringLiteral("kwin/effects/plugins"),
    qt_static_plugin_colorpicker_factory()
);
}
};
static Staticcolorpicker_factoryPluginInstance staticcolorpicker_factoryInstance;

extern const QT_PREPEND_NAMESPACE(QStaticPlugin) qt_static_plugin_diminactive_factory();
class Staticdiminactive_factoryPluginInstance
{
public:
Staticdiminactive_factoryPluginInstance()
{
kRegisterStaticPluginFunction(
    QStringLiteral("diminactive"),
    QStringLiteral("kwin/effects/plugins"),
    qt_static_plugin_diminactive_factory()
);
}
};
static Staticdiminactive_factoryPluginInstance staticdiminactive_factoryInstance;

extern const QT_PREPEND_NAMESPACE(QStaticPlugin) qt_static_plugin_fallapart_factory();
class Staticfallapart_factoryPluginInstance
{
public:
Staticfallapart_factoryPluginInstance()
{
kRegisterStaticPluginFunction(
    QStringLiteral("fallapart"),
    QStringLiteral("kwin/effects/plugins"),
    qt_static_plugin_fallapart_factory()
);
}
};
static Staticfallapart_factoryPluginInstance staticfallapart_factoryInstance;

extern const QT_PREPEND_NAMESPACE(QStaticPlugin) qt_static_plugin_glide_factory();
class Staticglide_factoryPluginInstance
{
public:
Staticglide_factoryPluginInstance()
{
kRegisterStaticPluginFunction(
    QStringLiteral("glide"),
    QStringLiteral("kwin/effects/plugins"),
    qt_static_plugin_glide_factory()
);
}
};
static Staticglide_factoryPluginInstance staticglide_factoryInstance;

extern const QT_PREPEND_NAMESPACE(QStaticPlugin) qt_static_plugin_hidecursor_factory();
class Statichidecursor_factoryPluginInstance
{
public:
Statichidecursor_factoryPluginInstance()
{
kRegisterStaticPluginFunction(
    QStringLiteral("hidecursor"),
    QStringLiteral("kwin/effects/plugins"),
    qt_static_plugin_hidecursor_factory()
);
}
};
static Statichidecursor_factoryPluginInstance statichidecursor_factoryInstance;

extern const QT_PREPEND_NAMESPACE(QStaticPlugin) qt_static_plugin_highlightwindow_factory();
class Statichighlightwindow_factoryPluginInstance
{
public:
Statichighlightwindow_factoryPluginInstance()
{
kRegisterStaticPluginFunction(
    QStringLiteral("highlightwindow"),
    QStringLiteral("kwin/effects/plugins"),
    qt_static_plugin_highlightwindow_factory()
);
}
};
static Statichighlightwindow_factoryPluginInstance statichighlightwindow_factoryInstance;

extern const QT_PREPEND_NAMESPACE(QStaticPlugin) qt_static_plugin_invert_factory();
class Staticinvert_factoryPluginInstance
{
public:
Staticinvert_factoryPluginInstance()
{
kRegisterStaticPluginFunction(
    QStringLiteral("invert"),
    QStringLiteral("kwin/effects/plugins"),
    qt_static_plugin_invert_factory()
);
}
};
static Staticinvert_factoryPluginInstance staticinvert_factoryInstance;

extern const QT_PREPEND_NAMESPACE(QStaticPlugin) qt_static_plugin_kscreen_factory();
class Statickscreen_factoryPluginInstance
{
public:
Statickscreen_factoryPluginInstance()
{
kRegisterStaticPluginFunction(
    QStringLiteral("kscreen"),
    QStringLiteral("kwin/effects/plugins"),
    qt_static_plugin_kscreen_factory()
);
}
};
static Statickscreen_factoryPluginInstance statickscreen_factoryInstance;

extern const QT_PREPEND_NAMESPACE(QStaticPlugin) qt_static_plugin_magiclamp_factory();
class Staticmagiclamp_factoryPluginInstance
{
public:
Staticmagiclamp_factoryPluginInstance()
{
kRegisterStaticPluginFunction(
    QStringLiteral("magiclamp"),
    QStringLiteral("kwin/effects/plugins"),
    qt_static_plugin_magiclamp_factory()
);
}
};
static Staticmagiclamp_factoryPluginInstance staticmagiclamp_factoryInstance;

extern const QT_PREPEND_NAMESPACE(QStaticPlugin) qt_static_plugin_magnifier_factory();
class Staticmagnifier_factoryPluginInstance
{
public:
Staticmagnifier_factoryPluginInstance()
{
kRegisterStaticPluginFunction(
    QStringLiteral("magnifier"),
    QStringLiteral("kwin/effects/plugins"),
    qt_static_plugin_magnifier_factory()
);
}
};
static Staticmagnifier_factoryPluginInstance staticmagnifier_factoryInstance;

extern const QT_PREPEND_NAMESPACE(QStaticPlugin) qt_static_plugin_mouseclick_factory();
class Staticmouseclick_factoryPluginInstance
{
public:
Staticmouseclick_factoryPluginInstance()
{
kRegisterStaticPluginFunction(
    QStringLiteral("mouseclick"),
    QStringLiteral("kwin/effects/plugins"),
    qt_static_plugin_mouseclick_factory()
);
}
};
static Staticmouseclick_factoryPluginInstance staticmouseclick_factoryInstance;

extern const QT_PREPEND_NAMESPACE(QStaticPlugin) qt_static_plugin_mousemark_factory();
class Staticmousemark_factoryPluginInstance
{
public:
Staticmousemark_factoryPluginInstance()
{
kRegisterStaticPluginFunction(
    QStringLiteral("mousemark"),
    QStringLiteral("kwin/effects/plugins"),
    qt_static_plugin_mousemark_factory()
);
}
};
static Staticmousemark_factoryPluginInstance staticmousemark_factoryInstance;

extern const QT_PREPEND_NAMESPACE(QStaticPlugin) qt_static_plugin_outputlocator_factory();
class Staticoutputlocator_factoryPluginInstance
{
public:
Staticoutputlocator_factoryPluginInstance()
{
kRegisterStaticPluginFunction(
    QStringLiteral("outputlocator"),
    QStringLiteral("kwin/effects/plugins"),
    qt_static_plugin_outputlocator_factory()
);
}
};
static Staticoutputlocator_factoryPluginInstance staticoutputlocator_factoryInstance;

extern const QT_PREPEND_NAMESPACE(QStaticPlugin) qt_static_plugin_overview_factory();
class Staticoverview_factoryPluginInstance
{
public:
Staticoverview_factoryPluginInstance()
{
kRegisterStaticPluginFunction(
    QStringLiteral("overview"),
    QStringLiteral("kwin/effects/plugins"),
    qt_static_plugin_overview_factory()
);
}
};
static Staticoverview_factoryPluginInstance staticoverview_factoryInstance;

extern const QT_PREPEND_NAMESPACE(QStaticPlugin) qt_static_plugin_screenedge_factory();
class Staticscreenedge_factoryPluginInstance
{
public:
Staticscreenedge_factoryPluginInstance()
{
kRegisterStaticPluginFunction(
    QStringLiteral("screenedge"),
    QStringLiteral("kwin/effects/plugins"),
    qt_static_plugin_screenedge_factory()
);
}
};
static Staticscreenedge_factoryPluginInstance staticscreenedge_factoryInstance;

extern const QT_PREPEND_NAMESPACE(QStaticPlugin) qt_static_plugin_screentransform_factory();
class Staticscreentransform_factoryPluginInstance
{
public:
Staticscreentransform_factoryPluginInstance()
{
kRegisterStaticPluginFunction(
    QStringLiteral("screentransform"),
    QStringLiteral("kwin/effects/plugins"),
    qt_static_plugin_screentransform_factory()
);
}
};
static Staticscreentransform_factoryPluginInstance staticscreentransform_factoryInstance;

extern const QT_PREPEND_NAMESPACE(QStaticPlugin) qt_static_plugin_shakecursor_factory();
class Staticshakecursor_factoryPluginInstance
{
public:
Staticshakecursor_factoryPluginInstance()
{
kRegisterStaticPluginFunction(
    QStringLiteral("shakecursor"),
    QStringLiteral("kwin/effects/plugins"),
    qt_static_plugin_shakecursor_factory()
);
}
};
static Staticshakecursor_factoryPluginInstance staticshakecursor_factoryInstance;

extern const QT_PREPEND_NAMESPACE(QStaticPlugin) qt_static_plugin_sheet_factory();
class Staticsheet_factoryPluginInstance
{
public:
Staticsheet_factoryPluginInstance()
{
kRegisterStaticPluginFunction(
    QStringLiteral("sheet"),
    QStringLiteral("kwin/effects/plugins"),
    qt_static_plugin_sheet_factory()
);
}
};
static Staticsheet_factoryPluginInstance staticsheet_factoryInstance;

extern const QT_PREPEND_NAMESPACE(QStaticPlugin) qt_static_plugin_showcompositing_factory();
class Staticshowcompositing_factoryPluginInstance
{
public:
Staticshowcompositing_factoryPluginInstance()
{
kRegisterStaticPluginFunction(
    QStringLiteral("showcompositing"),
    QStringLiteral("kwin/effects/plugins"),
    qt_static_plugin_showcompositing_factory()
);
}
};
static Staticshowcompositing_factoryPluginInstance staticshowcompositing_factoryInstance;

extern const QT_PREPEND_NAMESPACE(QStaticPlugin) qt_static_plugin_showfps_factory();
class Staticshowfps_factoryPluginInstance
{
public:
Staticshowfps_factoryPluginInstance()
{
kRegisterStaticPluginFunction(
    QStringLiteral("showfps"),
    QStringLiteral("kwin/effects/plugins"),
    qt_static_plugin_showfps_factory()
);
}
};
static Staticshowfps_factoryPluginInstance staticshowfps_factoryInstance;

extern const QT_PREPEND_NAMESPACE(QStaticPlugin) qt_static_plugin_showpaint_factory();
class Staticshowpaint_factoryPluginInstance
{
public:
Staticshowpaint_factoryPluginInstance()
{
kRegisterStaticPluginFunction(
    QStringLiteral("showpaint"),
    QStringLiteral("kwin/effects/plugins"),
    qt_static_plugin_showpaint_factory()
);
}
};
static Staticshowpaint_factoryPluginInstance staticshowpaint_factoryInstance;

extern const QT_PREPEND_NAMESPACE(QStaticPlugin) qt_static_plugin_slide_factory();
class Staticslide_factoryPluginInstance
{
public:
Staticslide_factoryPluginInstance()
{
kRegisterStaticPluginFunction(
    QStringLiteral("slide"),
    QStringLiteral("kwin/effects/plugins"),
    qt_static_plugin_slide_factory()
);
}
};
static Staticslide_factoryPluginInstance staticslide_factoryInstance;

extern const QT_PREPEND_NAMESPACE(QStaticPlugin) qt_static_plugin_slideback_factory();
class Staticslideback_factoryPluginInstance
{
public:
Staticslideback_factoryPluginInstance()
{
kRegisterStaticPluginFunction(
    QStringLiteral("slideback"),
    QStringLiteral("kwin/effects/plugins"),
    qt_static_plugin_slideback_factory()
);
}
};
static Staticslideback_factoryPluginInstance staticslideback_factoryInstance;

extern const QT_PREPEND_NAMESPACE(QStaticPlugin) qt_static_plugin_slidingnotifications_factory();
class Staticslidingnotifications_factoryPluginInstance
{
public:
Staticslidingnotifications_factoryPluginInstance()
{
kRegisterStaticPluginFunction(
    QStringLiteral("slidingnotifications"),
    QStringLiteral("kwin/effects/plugins"),
    qt_static_plugin_slidingnotifications_factory()
);
}
};
static Staticslidingnotifications_factoryPluginInstance staticslidingnotifications_factoryInstance;

extern const QT_PREPEND_NAMESPACE(QStaticPlugin) qt_static_plugin_slidingpopups_factory();
class Staticslidingpopups_factoryPluginInstance
{
public:
Staticslidingpopups_factoryPluginInstance()
{
kRegisterStaticPluginFunction(
    QStringLiteral("slidingpopups"),
    QStringLiteral("kwin/effects/plugins"),
    qt_static_plugin_slidingpopups_factory()
);
}
};
static Staticslidingpopups_factoryPluginInstance staticslidingpopups_factoryInstance;

extern const QT_PREPEND_NAMESPACE(QStaticPlugin) qt_static_plugin_startupfeedback_factory();
class Staticstartupfeedback_factoryPluginInstance
{
public:
Staticstartupfeedback_factoryPluginInstance()
{
kRegisterStaticPluginFunction(
    QStringLiteral("startupfeedback"),
    QStringLiteral("kwin/effects/plugins"),
    qt_static_plugin_startupfeedback_factory()
);
}
};
static Staticstartupfeedback_factoryPluginInstance staticstartupfeedback_factoryInstance;

extern const QT_PREPEND_NAMESPACE(QStaticPlugin) qt_static_plugin_systembell_factory();
class Staticsystembell_factoryPluginInstance
{
public:
Staticsystembell_factoryPluginInstance()
{
kRegisterStaticPluginFunction(
    QStringLiteral("systembell"),
    QStringLiteral("kwin/effects/plugins"),
    qt_static_plugin_systembell_factory()
);
}
};
static Staticsystembell_factoryPluginInstance staticsystembell_factoryInstance;

extern const QT_PREPEND_NAMESPACE(QStaticPlugin) qt_static_plugin_thumbnailaside_factory();
class Staticthumbnailaside_factoryPluginInstance
{
public:
Staticthumbnailaside_factoryPluginInstance()
{
kRegisterStaticPluginFunction(
    QStringLiteral("thumbnailaside"),
    QStringLiteral("kwin/effects/plugins"),
    qt_static_plugin_thumbnailaside_factory()
);
}
};
static Staticthumbnailaside_factoryPluginInstance staticthumbnailaside_factoryInstance;

extern const QT_PREPEND_NAMESPACE(QStaticPlugin) qt_static_plugin_tileseditor_factory();
class Statictileseditor_factoryPluginInstance
{
public:
Statictileseditor_factoryPluginInstance()
{
kRegisterStaticPluginFunction(
    QStringLiteral("tileseditor"),
    QStringLiteral("kwin/effects/plugins"),
    qt_static_plugin_tileseditor_factory()
);
}
};
static Statictileseditor_factoryPluginInstance statictileseditor_factoryInstance;

extern const QT_PREPEND_NAMESPACE(QStaticPlugin) qt_static_plugin_touchpoints_factory();
class Statictouchpoints_factoryPluginInstance
{
public:
Statictouchpoints_factoryPluginInstance()
{
kRegisterStaticPluginFunction(
    QStringLiteral("touchpoints"),
    QStringLiteral("kwin/effects/plugins"),
    qt_static_plugin_touchpoints_factory()
);
}
};
static Statictouchpoints_factoryPluginInstance statictouchpoints_factoryInstance;

extern const QT_PREPEND_NAMESPACE(QStaticPlugin) qt_static_plugin_trackmouse_factory();
class Statictrackmouse_factoryPluginInstance
{
public:
Statictrackmouse_factoryPluginInstance()
{
kRegisterStaticPluginFunction(
    QStringLiteral("trackmouse"),
    QStringLiteral("kwin/effects/plugins"),
    qt_static_plugin_trackmouse_factory()
);
}
};
static Statictrackmouse_factoryPluginInstance statictrackmouse_factoryInstance;

extern const QT_PREPEND_NAMESPACE(QStaticPlugin) qt_static_plugin_windowview_factory();
class Staticwindowview_factoryPluginInstance
{
public:
Staticwindowview_factoryPluginInstance()
{
kRegisterStaticPluginFunction(
    QStringLiteral("windowview"),
    QStringLiteral("kwin/effects/plugins"),
    qt_static_plugin_windowview_factory()
);
}
};
static Staticwindowview_factoryPluginInstance staticwindowview_factoryInstance;

extern const QT_PREPEND_NAMESPACE(QStaticPlugin) qt_static_plugin_wobblywindows_factory();
class Staticwobblywindows_factoryPluginInstance
{
public:
Staticwobblywindows_factoryPluginInstance()
{
kRegisterStaticPluginFunction(
    QStringLiteral("wobblywindows"),
    QStringLiteral("kwin/effects/plugins"),
    qt_static_plugin_wobblywindows_factory()
);
}
};
static Staticwobblywindows_factoryPluginInstance staticwobblywindows_factoryInstance;

extern const QT_PREPEND_NAMESPACE(QStaticPlugin) qt_static_plugin_zoom_factory();
class Staticzoom_factoryPluginInstance
{
public:
Staticzoom_factoryPluginInstance()
{
kRegisterStaticPluginFunction(
    QStringLiteral("zoom"),
    QStringLiteral("kwin/effects/plugins"),
    qt_static_plugin_zoom_factory()
);
}
};
static Staticzoom_factoryPluginInstance staticzoom_factoryInstance;
