// This file is generated by kconfig_compiler_kf6 from kwintabboxsettings.kcfg.
// All changes you do to this file will be lost.

#include "kwintabboxsettings.h"

using namespace KWin::TabBox;

TabBoxSettings::TabBoxSettings( const QString & TabBoxGroup, QObject *parent )
  : KConfigSkeleton( QStringLiteral( "kwinrc" ) )
  , mParamTabBoxGroup(TabBoxGroup)
{
  setParent(parent);
  setCurrentGroup( QStringLiteral( "%1" ).arg( mParamTabBoxGroup ) );

  KConfigSkeleton::ItemInt  *itemDesktopMode;
  itemDesktopMode = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "DesktopMode" ), mDesktopMode, TabBoxConfig::defaultDesktopMode() );
  addItem( itemDesktopMode, QStringLiteral( "DesktopMode" ) );
  KConfigSkeleton::ItemInt  *itemActivitiesMode;
  itemActivitiesMode = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "ActivitiesMode" ), mActivitiesMode, TabBoxConfig::defaultActivitiesMode() );
  addItem( itemActivitiesMode, QStringLiteral( "ActivitiesMode" ) );
  KConfigSkeleton::ItemInt  *itemApplicationsMode;
  itemApplicationsMode = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "ApplicationsMode" ), mApplicationsMode, TabBoxConfig::defaultApplicationsMode() );
  addItem( itemApplicationsMode, QStringLiteral( "ApplicationsMode" ) );
  KConfigSkeleton::ItemInt  *itemOrderMinimizedMode;
  itemOrderMinimizedMode = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "OrderMinimizedMode" ), mOrderMinimizedMode, TabBoxConfig::defaultOrderMinimizedMode() );
  addItem( itemOrderMinimizedMode, QStringLiteral( "OrderMinimizedMode" ) );
  KConfigSkeleton::ItemInt  *itemMinimizedMode;
  itemMinimizedMode = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "MinimizedMode" ), mMinimizedMode, TabBoxConfig::defaultMinimizedMode() );
  addItem( itemMinimizedMode, QStringLiteral( "MinimizedMode" ) );
  KConfigSkeleton::ItemInt  *itemShowDesktopMode;
  itemShowDesktopMode = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "ShowDesktopMode" ), mShowDesktopMode, TabBoxConfig::defaultShowDesktopMode() );
  addItem( itemShowDesktopMode, QStringLiteral( "ShowDesktopMode" ) );
  KConfigSkeleton::ItemInt  *itemMultiScreenMode;
  itemMultiScreenMode = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "MultiScreenMode" ), mMultiScreenMode, TabBoxConfig::defaultMultiScreenMode() );
  addItem( itemMultiScreenMode, QStringLiteral( "MultiScreenMode" ) );
  KConfigSkeleton::ItemInt  *itemSwitchingMode;
  itemSwitchingMode = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "SwitchingMode" ), mSwitchingMode, TabBoxConfig::defaultSwitchingMode() );
  addItem( itemSwitchingMode, QStringLiteral( "SwitchingMode" ) );
  KConfigSkeleton::ItemInt  *itemShowScreenMode;
  itemShowScreenMode = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "ShowScreenMode" ), mShowScreenMode, TabBoxConfig::defaultShowScreenMode() );
  addItem( itemShowScreenMode, QStringLiteral( "ShowScreenMode" ) );
  KConfigSkeleton::ItemString  *itemLayoutName;
  itemLayoutName = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "LayoutName" ), mLayoutName, TabBoxConfig::defaultLayoutName() );
  addItem( itemLayoutName, QStringLiteral( "LayoutName" ) );
  KConfigSkeleton::ItemBool  *itemShowTabBox;
  itemShowTabBox = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowTabBox" ), mShowTabBox, TabBoxConfig::defaultShowTabBox() );
  addItem( itemShowTabBox, QStringLiteral( "ShowTabBox" ) );
  KConfigSkeleton::ItemBool  *itemHighlightWindows;
  itemHighlightWindows = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "HighlightWindows" ), mHighlightWindows, TabBoxConfig::defaultHighlightWindow() );
  addItem( itemHighlightWindows, QStringLiteral( "HighlightWindows" ) );
  KConfigSkeleton::ItemInt  *itemDelayTime;
  itemDelayTime = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "DelayTime" ), mDelayTime, 90 );
  addItem( itemDelayTime, QStringLiteral( "DelayTime" ) );
}

int TabBoxSettings::defaultDesktopModeValue_helper() const
{

  return TabBoxConfig::defaultDesktopMode();
}

int TabBoxSettings::defaultActivitiesModeValue_helper() const
{

  return TabBoxConfig::defaultActivitiesMode();
}

int TabBoxSettings::defaultApplicationsModeValue_helper() const
{

  return TabBoxConfig::defaultApplicationsMode();
}

int TabBoxSettings::defaultOrderMinimizedModeValue_helper() const
{

  return TabBoxConfig::defaultOrderMinimizedMode();
}

int TabBoxSettings::defaultMinimizedModeValue_helper() const
{

  return TabBoxConfig::defaultMinimizedMode();
}

int TabBoxSettings::defaultShowDesktopModeValue_helper() const
{

  return TabBoxConfig::defaultShowDesktopMode();
}

int TabBoxSettings::defaultMultiScreenModeValue_helper() const
{

  return TabBoxConfig::defaultMultiScreenMode();
}

int TabBoxSettings::defaultSwitchingModeValue_helper() const
{

  return TabBoxConfig::defaultSwitchingMode();
}

int TabBoxSettings::defaultShowScreenModeValue_helper() const
{

  return TabBoxConfig::defaultShowScreenMode();
}

QString TabBoxSettings::defaultLayoutNameValue_helper() const
{

  return TabBoxConfig::defaultLayoutName();
}

bool TabBoxSettings::defaultShowTabBoxValue_helper() const
{

  return TabBoxConfig::defaultShowTabBox();
}

bool TabBoxSettings::defaultHighlightWindowsValue_helper() const
{

  return TabBoxConfig::defaultHighlightWindow();
}

int TabBoxSettings::defaultDelayTimeValue_helper() const
{

  return 90;
}

TabBoxSettings::~TabBoxSettings()
{
}

