// This file is generated by kconfig_compiler_kf6 from animationskdeglobalssettings.kcfg.
// All changes you do to this file will be lost.

#include "animationskdeglobalssettings.h"

using namespace KWin;

AnimationsGlobalsSettings::AnimationsGlobalsSettings( QObject *parent )
  : KConfigSkeleton( QStringLiteral( "kdeglobals" ) )
{
  setParent(parent);
  KConfigCompilerSignallingItem::NotifyFunction notifyFunction = static_cast<KConfigCompilerSignallingItem::NotifyFunction>(&AnimationsGlobalsSettings::itemChanged);

  setCurrentGroup( QStringLiteral( "KDE" ) );

  KConfigCompilerSignallingItem  *itemAnimationDurationFactor;
  KConfigSkeleton::ItemDouble  *innerItemAnimationDurationFactor;
  innerItemAnimationDurationFactor = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "AnimationDurationFactor" ), mAnimationDurationFactor, 1.0 );
  itemAnimationDurationFactor = new KConfigCompilerSignallingItem(innerItemAnimationDurationFactor, this, notifyFunction, signalAnimationDurationFactorChanged);
  itemAnimationDurationFactor->setWriteFlags(KConfigBase::Notify);
  addItem( itemAnimationDurationFactor, QStringLiteral( "animationDurationFactor" ) );
}

double AnimationsGlobalsSettings::defaultAnimationDurationFactorValue_helper() const
{

  return 1.0;
}

AnimationsGlobalsSettings::~AnimationsGlobalsSettings()
{
}


void AnimationsGlobalsSettings::itemChanged(quint64 signalFlag) {

  switch (signalFlag) {
  case signalAnimationDurationFactorChanged:
    Q_EMIT animationDurationFactorChanged();
    break;
  }
}
