// This file is generated by kconfig_compiler_kf6 from kwinscreenedgesettings.kcfg.
// All changes you do to this file will be lost.

#include "kwinscreenedgesettings.h"

using namespace KWin;

KWinScreenEdgeSettings::KWinScreenEdgeSettings( QObject *parent )
  : KConfigSkeleton( QStringLiteral( "kwinrc" ) )
{
  setParent(parent);
  setCurrentGroup( QStringLiteral( "Windows" ) );

  KConfigSkeleton::ItemInt  *itemElectricBorders;
  itemElectricBorders = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "ElectricBorders" ), mElectricBorders, 0 );
  addItem( itemElectricBorders, QStringLiteral( "ElectricBorders" ) );
  KConfigSkeleton::ItemInt  *itemElectricBorderDelay;
  itemElectricBorderDelay = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "ElectricBorderDelay" ), mElectricBorderDelay, 75 );
  addItem( itemElectricBorderDelay, QStringLiteral( "ElectricBorderDelay" ) );
  KConfigSkeleton::ItemInt  *itemElectricBorderCooldown;
  itemElectricBorderCooldown = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "ElectricBorderCooldown" ), mElectricBorderCooldown, 350 );
  addItem( itemElectricBorderCooldown, QStringLiteral( "ElectricBorderCooldown" ) );
  KConfigSkeleton::ItemBool  *itemElectricBorderMaximize;
  itemElectricBorderMaximize = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ElectricBorderMaximize" ), mElectricBorderMaximize, true );
  addItem( itemElectricBorderMaximize, QStringLiteral( "ElectricBorderMaximize" ) );
  KConfigSkeleton::ItemBool  *itemElectricBorderTiling;
  itemElectricBorderTiling = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ElectricBorderTiling" ), mElectricBorderTiling, true );
  addItem( itemElectricBorderTiling, QStringLiteral( "ElectricBorderTiling" ) );
  KConfigSkeleton::ItemDouble  *itemElectricBorderCornerRatio;
  itemElectricBorderCornerRatio = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "ElectricBorderCornerRatio" ), mElectricBorderCornerRatio, 0.25 );
  addItem( itemElectricBorderCornerRatio, QStringLiteral( "ElectricBorderCornerRatio" ) );
  KConfigSkeleton::ItemBool  *itemElectricBorderAllScreenCorner;
  itemElectricBorderAllScreenCorner = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ElectricBorderAllScreenCorner" ), mElectricBorderAllScreenCorner, true );
  addItem( itemElectricBorderAllScreenCorner, QStringLiteral( "ElectricBorderAllScreenCorner" ) );

  setCurrentGroup( QStringLiteral( "ElectricBorders" ) );

  KConfigSkeleton::ItemString  *itemTop;
  itemTop = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Top" ), mTop, QStringLiteral( "None" ) );
  addItem( itemTop, QStringLiteral( "Top" ) );
  KConfigSkeleton::ItemString  *itemTopRight;
  itemTopRight = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "TopRight" ), mTopRight, QStringLiteral( "None" ) );
  addItem( itemTopRight, QStringLiteral( "TopRight" ) );
  KConfigSkeleton::ItemString  *itemRight;
  itemRight = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Right" ), mRight, QStringLiteral( "None" ) );
  addItem( itemRight, QStringLiteral( "Right" ) );
  KConfigSkeleton::ItemString  *itemBottomRight;
  itemBottomRight = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "BottomRight" ), mBottomRight, QStringLiteral( "None" ) );
  addItem( itemBottomRight, QStringLiteral( "BottomRight" ) );
  KConfigSkeleton::ItemString  *itemBottom;
  itemBottom = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Bottom" ), mBottom, QStringLiteral( "None" ) );
  addItem( itemBottom, QStringLiteral( "Bottom" ) );
  KConfigSkeleton::ItemString  *itemBottomLeft;
  itemBottomLeft = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "BottomLeft" ), mBottomLeft, QStringLiteral( "None" ) );
  addItem( itemBottomLeft, QStringLiteral( "BottomLeft" ) );
  KConfigSkeleton::ItemString  *itemLeft;
  itemLeft = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Left" ), mLeft, QStringLiteral( "None" ) );
  addItem( itemLeft, QStringLiteral( "Left" ) );
  KConfigSkeleton::ItemString  *itemTopLeft;
  itemTopLeft = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "TopLeft" ), mTopLeft, QStringLiteral( "None" ) );
  addItem( itemTopLeft, QStringLiteral( "TopLeft" ) );

  setCurrentGroup( QStringLiteral( "Effect-windowview" ) );

  QList<int> defaultBorderActivateAll;
  defaultBorderActivateAll.append( ElectricNone );

  KConfigSkeleton::ItemIntList  *itemBorderActivateAll;
  itemBorderActivateAll = new KConfigSkeleton::ItemIntList( currentGroup(), QStringLiteral( "BorderActivateAll" ), mBorderActivateAll, defaultBorderActivateAll );
  addItem( itemBorderActivateAll, QStringLiteral( "BorderActivateAll" ) );
  QList<int> defaultBorderActivatePresentWindows;
  defaultBorderActivatePresentWindows.append( ElectricNone );

  KConfigSkeleton::ItemIntList  *itemBorderActivatePresentWindows;
  itemBorderActivatePresentWindows = new KConfigSkeleton::ItemIntList( currentGroup(), QStringLiteral( "BorderActivate" ), mBorderActivatePresentWindows, defaultBorderActivatePresentWindows );
  addItem( itemBorderActivatePresentWindows, QStringLiteral( "BorderActivatePresentWindows" ) );
  QList<int> defaultBorderActivateClass;
  defaultBorderActivateClass.append( ElectricNone );

  KConfigSkeleton::ItemIntList  *itemBorderActivateClass;
  itemBorderActivateClass = new KConfigSkeleton::ItemIntList( currentGroup(), QStringLiteral( "BorderActivateClass" ), mBorderActivateClass, defaultBorderActivateClass );
  addItem( itemBorderActivateClass, QStringLiteral( "BorderActivateClass" ) );

  setCurrentGroup( QStringLiteral( "Effect-overview" ) );

  QList<int> defaultBorderActivateOverview;
  defaultBorderActivateOverview.append( ElectricTopLeft );

  KConfigSkeleton::ItemIntList  *itemBorderActivateOverview;
  itemBorderActivateOverview = new KConfigSkeleton::ItemIntList( currentGroup(), QStringLiteral( "BorderActivate" ), mBorderActivateOverview, defaultBorderActivateOverview );
  addItem( itemBorderActivateOverview, QStringLiteral( "BorderActivateOverview" ) );
  QList<int> defaultBorderActivateGrid;
  defaultBorderActivateGrid.append( ElectricNone );

  KConfigSkeleton::ItemIntList  *itemBorderActivateGrid;
  itemBorderActivateGrid = new KConfigSkeleton::ItemIntList( currentGroup(), QStringLiteral( "GridBorderActivate" ), mBorderActivateGrid, defaultBorderActivateGrid );
  addItem( itemBorderActivateGrid, QStringLiteral( "BorderActivateGrid" ) );

  setCurrentGroup( QStringLiteral( "TabBox" ) );

  QList<int> defaultBorderActivateTabBox;
  defaultBorderActivateTabBox.append( ElectricNone );

  KConfigSkeleton::ItemIntList  *itemBorderActivateTabBox;
  itemBorderActivateTabBox = new KConfigSkeleton::ItemIntList( currentGroup(), QStringLiteral( "BorderActivate" ), mBorderActivateTabBox, defaultBorderActivateTabBox );
  addItem( itemBorderActivateTabBox, QStringLiteral( "BorderActivateTabBox" ) );
  QList<int> defaultBorderAlternativeActivate;
  defaultBorderAlternativeActivate.append( ElectricNone );

  KConfigSkeleton::ItemIntList  *itemBorderAlternativeActivate;
  itemBorderAlternativeActivate = new KConfigSkeleton::ItemIntList( currentGroup(), QStringLiteral( "BorderAlternativeActivate" ), mBorderAlternativeActivate, defaultBorderAlternativeActivate );
  addItem( itemBorderAlternativeActivate, QStringLiteral( "BorderAlternativeActivate" ) );

  setCurrentGroup( QStringLiteral( "ScreenEdges" ) );

  KConfigSkeleton::ItemBool  *itemRemainActiveOnFullscreen;
  itemRemainActiveOnFullscreen = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "RemainActiveOnFullscreen" ), mRemainActiveOnFullscreen, false );
  addItem( itemRemainActiveOnFullscreen, QStringLiteral( "RemainActiveOnFullscreen" ) );

  setCurrentGroup( QStringLiteral( "EdgeBarrier" ) );

  KConfigSkeleton::ItemBool  *itemCornerBarrier;
  itemCornerBarrier = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "CornerBarrier" ), mCornerBarrier, true );
  addItem( itemCornerBarrier, QStringLiteral( "CornerBarrier" ) );
  KConfigSkeleton::ItemInt  *itemEdgeBarrier;
  itemEdgeBarrier = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "EdgeBarrier" ), mEdgeBarrier, 100 );
  itemEdgeBarrier->setMinValue(0);
  itemEdgeBarrier->setMaxValue(1000);
  addItem( itemEdgeBarrier, QStringLiteral( "EdgeBarrier" ) );
}

int KWinScreenEdgeSettings::defaultElectricBordersValue_helper() const
{

  return 0;
}

int KWinScreenEdgeSettings::defaultElectricBorderDelayValue_helper() const
{

  return 75;
}

int KWinScreenEdgeSettings::defaultElectricBorderCooldownValue_helper() const
{

  return 350;
}

bool KWinScreenEdgeSettings::defaultElectricBorderMaximizeValue_helper() const
{

  return true;
}

bool KWinScreenEdgeSettings::defaultElectricBorderTilingValue_helper() const
{

  return true;
}

double KWinScreenEdgeSettings::defaultElectricBorderCornerRatioValue_helper() const
{

  return 0.25;
}

bool KWinScreenEdgeSettings::defaultElectricBorderAllScreenCornerValue_helper() const
{

  return true;
}

QString KWinScreenEdgeSettings::defaultTopValue_helper() const
{

  return QStringLiteral( "None" );
}

QString KWinScreenEdgeSettings::defaultTopRightValue_helper() const
{

  return QStringLiteral( "None" );
}

QString KWinScreenEdgeSettings::defaultRightValue_helper() const
{

  return QStringLiteral( "None" );
}

QString KWinScreenEdgeSettings::defaultBottomRightValue_helper() const
{

  return QStringLiteral( "None" );
}

QString KWinScreenEdgeSettings::defaultBottomValue_helper() const
{

  return QStringLiteral( "None" );
}

QString KWinScreenEdgeSettings::defaultBottomLeftValue_helper() const
{

  return QStringLiteral( "None" );
}

QString KWinScreenEdgeSettings::defaultLeftValue_helper() const
{

  return QStringLiteral( "None" );
}

QString KWinScreenEdgeSettings::defaultTopLeftValue_helper() const
{

  return QStringLiteral( "None" );
}

QList<int> KWinScreenEdgeSettings::defaultBorderActivateAllValue_helper() const
{
  QList<int> defaultBorderActivateAll;
  defaultBorderActivateAll.append( ElectricNone );

  return defaultBorderActivateAll;
}

QList<int> KWinScreenEdgeSettings::defaultBorderActivatePresentWindowsValue_helper() const
{
  QList<int> defaultBorderActivatePresentWindows;
  defaultBorderActivatePresentWindows.append( ElectricNone );

  return defaultBorderActivatePresentWindows;
}

QList<int> KWinScreenEdgeSettings::defaultBorderActivateClassValue_helper() const
{
  QList<int> defaultBorderActivateClass;
  defaultBorderActivateClass.append( ElectricNone );

  return defaultBorderActivateClass;
}

QList<int> KWinScreenEdgeSettings::defaultBorderActivateOverviewValue_helper() const
{
  QList<int> defaultBorderActivateOverview;
  defaultBorderActivateOverview.append( ElectricTopLeft );

  return defaultBorderActivateOverview;
}

QList<int> KWinScreenEdgeSettings::defaultBorderActivateGridValue_helper() const
{
  QList<int> defaultBorderActivateGrid;
  defaultBorderActivateGrid.append( ElectricNone );

  return defaultBorderActivateGrid;
}

QList<int> KWinScreenEdgeSettings::defaultBorderActivateTabBoxValue_helper() const
{
  QList<int> defaultBorderActivateTabBox;
  defaultBorderActivateTabBox.append( ElectricNone );

  return defaultBorderActivateTabBox;
}

QList<int> KWinScreenEdgeSettings::defaultBorderAlternativeActivateValue_helper() const
{
  QList<int> defaultBorderAlternativeActivate;
  defaultBorderAlternativeActivate.append( ElectricNone );

  return defaultBorderAlternativeActivate;
}

bool KWinScreenEdgeSettings::defaultRemainActiveOnFullscreenValue_helper() const
{

  return false;
}

bool KWinScreenEdgeSettings::defaultCornerBarrierValue_helper() const
{

  return true;
}

int KWinScreenEdgeSettings::defaultEdgeBarrierValue_helper() const
{

  return 100;
}

KWinScreenEdgeSettings::~KWinScreenEdgeSettings()
{
}

