// This file is generated by kconfig_compiler_kf6 from rulesettings.kcfg.
// All changes you do to this file will be lost.

#include "rulesettings.h"

using namespace KWin;

RuleSettings::RuleSettings( KSharedConfig::Ptr config, const QString & ruleDescriptionOrNumber, QObject *parent )
  : KConfigSkeleton( std::move( config ) )
  , mParamruleDescriptionOrNumber(ruleDescriptionOrNumber)
{
  setParent(parent);
  setCurrentGroup( QStringLiteral( "%1" ).arg( mParamruleDescriptionOrNumber ) );

  KConfigSkeleton::ItemString  *itemDescription;
  itemDescription = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Description" ), mDescription );
  addItem( itemDescription, QStringLiteral( "description" ) );
  KConfigSkeleton::ItemString  *itemDescriptionLegacy;
  itemDescriptionLegacy = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "description" ), mDescriptionLegacy );
  addItem( itemDescriptionLegacy, QStringLiteral( "descriptionLegacy" ) );
  KConfigSkeleton::ItemBool  *itemDeleteRule;
  itemDeleteRule = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "deleteRule" ), mDeleteRule, false );
  addItem( itemDeleteRule, QStringLiteral( "DeleteRule" ) );
  KConfigSkeleton::ItemBool  *itemEnabled;
  itemEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "Enabled" ), mEnabled, true );
  addItem( itemEnabled, QStringLiteral( "enabled" ) );
  KConfigSkeleton::ItemString  *itemWmclass;
  itemWmclass = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "wmclass" ), mWmclass );
  addItem( itemWmclass, QStringLiteral( "wmclass" ) );
  KConfigSkeleton::ItemInt  *itemWmclassmatch;
  itemWmclassmatch = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "wmclassmatch" ), mWmclassmatch, Rules::UnimportantMatch );
  itemWmclassmatch->setMinValue(Rules::FirstStringMatch);
  itemWmclassmatch->setMaxValue(Rules::LastStringMatch);
  addItem( itemWmclassmatch, QStringLiteral( "wmclassmatch" ) );
  KConfigSkeleton::ItemBool  *itemWmclasscomplete;
  itemWmclasscomplete = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "wmclasscomplete" ), mWmclasscomplete, Rules::UnimportantMatch );
  addItem( itemWmclasscomplete, QStringLiteral( "wmclasscomplete" ) );
  KConfigSkeleton::ItemString  *itemWindowrole;
  itemWindowrole = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "windowrole" ), mWindowrole );
  addItem( itemWindowrole, QStringLiteral( "windowrole" ) );
  KConfigSkeleton::ItemInt  *itemWindowrolematch;
  itemWindowrolematch = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "windowrolematch" ), mWindowrolematch, Rules::UnimportantMatch );
  itemWindowrolematch->setMinValue(Rules::FirstStringMatch);
  itemWindowrolematch->setMaxValue(Rules::LastStringMatch);
  addItem( itemWindowrolematch, QStringLiteral( "windowrolematch" ) );
  KConfigSkeleton::ItemString  *itemTitle;
  itemTitle = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "title" ), mTitle );
  addItem( itemTitle, QStringLiteral( "title" ) );
  KConfigSkeleton::ItemInt  *itemTitlematch;
  itemTitlematch = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "titlematch" ), mTitlematch, Rules::UnimportantMatch );
  itemTitlematch->setMinValue(Rules::FirstStringMatch);
  itemTitlematch->setMaxValue(Rules::LastStringMatch);
  addItem( itemTitlematch, QStringLiteral( "titlematch" ) );
  KConfigSkeleton::ItemString  *itemClientmachine;
  itemClientmachine = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "clientmachine" ), mClientmachine );
  addItem( itemClientmachine, QStringLiteral( "clientmachine" ) );
  KConfigSkeleton::ItemInt  *itemClientmachinematch;
  itemClientmachinematch = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "clientmachinematch" ), mClientmachinematch, Rules::UnimportantMatch );
  itemClientmachinematch->setMinValue(Rules::FirstStringMatch);
  itemClientmachinematch->setMaxValue(Rules::LastStringMatch);
  addItem( itemClientmachinematch, QStringLiteral( "clientmachinematch" ) );
  KConfigSkeleton::ItemString  *itemTag;
  itemTag = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "tag" ), mTag );
  addItem( itemTag, QStringLiteral( "tag" ) );
  KConfigSkeleton::ItemInt  *itemTagmatch;
  itemTagmatch = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "tagmatch" ), mTagmatch, Rules::UnimportantMatch );
  itemTagmatch->setMinValue(Rules::FirstStringMatch);
  itemTagmatch->setMaxValue(Rules::LastStringMatch);
  addItem( itemTagmatch, QStringLiteral( "tagmatch" ) );
  KConfigSkeleton::ItemBool  *itemHastransientparent;
  itemHastransientparent = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "hastransientparent" ), mHastransientparent, false );
  addItem( itemHastransientparent, QStringLiteral( "hastransientparent" ) );
  KConfigSkeleton::ItemInt  *itemHastransientparentmatch;
  itemHastransientparentmatch = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "hastransientparentmatch" ), mHastransientparentmatch, Rules::UnimportantBoolMatch );
  itemHastransientparentmatch->setMinValue(Rules::FirstBoolMatch);
  itemHastransientparentmatch->setMaxValue(Rules::LastBoolMatch);
  addItem( itemHastransientparentmatch, QStringLiteral( "hastransientparentmatch" ) );
  KConfigSkeleton::ItemUInt  *itemTypes;
  itemTypes = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "types" ), mTypes, NET::AllTypesMask );
  addItem( itemTypes, QStringLiteral( "types" ) );
  QList<KConfigSkeleton::ItemEnum::Choice> valuesplacement;
  KConfigSkeleton::ItemEnum  *itemPlacement;
  itemPlacement = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "placement" ), mPlacement, valuesplacement, int(PlacementCentered) );
  addItem( itemPlacement, QStringLiteral( "placement" ) );
  KConfigSkeleton::ItemInt  *itemPlacementrule;
  itemPlacementrule = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "placementrule" ), mPlacementrule, Rules::UnusedForceRule );
  addItem( itemPlacementrule, QStringLiteral( "placementrule" ) );
  KConfigSkeleton::ItemPoint  *itemPosition;
  itemPosition = new KConfigSkeleton::ItemPoint( currentGroup(), QStringLiteral( "position" ), mPosition, invalidPoint );
  addItem( itemPosition, QStringLiteral( "position" ) );
  KConfigSkeleton::ItemInt  *itemPositionrule;
  itemPositionrule = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "positionrule" ), mPositionrule, Rules::UnusedSetRule );
  itemPositionrule->setMinValue(Rules::UnusedSetRule);
  itemPositionrule->setMaxValue(static_cast<Rules::SetRule>(Rules::ForceTemporarily));
  addItem( itemPositionrule, QStringLiteral( "positionrule" ) );
  KConfigSkeleton::ItemSize  *itemSize;
  itemSize = new KConfigSkeleton::ItemSize( currentGroup(), QStringLiteral( "size" ), mSize );
  addItem( itemSize, QStringLiteral( "size" ) );
  KConfigSkeleton::ItemInt  *itemSizerule;
  itemSizerule = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "sizerule" ), mSizerule, Rules::UnusedSetRule );
  itemSizerule->setMinValue(Rules::UnusedSetRule);
  itemSizerule->setMaxValue(static_cast<Rules::SetRule>(Rules::ForceTemporarily));
  addItem( itemSizerule, QStringLiteral( "sizerule" ) );
  KConfigSkeleton::ItemSize  *itemMinsize;
  itemMinsize = new KConfigSkeleton::ItemSize( currentGroup(), QStringLiteral( "minsize" ), mMinsize );
  addItem( itemMinsize, QStringLiteral( "minsize" ) );
  KConfigSkeleton::ItemInt  *itemMinsizerule;
  itemMinsizerule = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "minsizerule" ), mMinsizerule, Rules::UnusedForceRule );
  addItem( itemMinsizerule, QStringLiteral( "minsizerule" ) );
  KConfigSkeleton::ItemSize  *itemMaxsize;
  itemMaxsize = new KConfigSkeleton::ItemSize( currentGroup(), QStringLiteral( "maxsize" ), mMaxsize );
  addItem( itemMaxsize, QStringLiteral( "maxsize" ) );
  KConfigSkeleton::ItemInt  *itemMaxsizerule;
  itemMaxsizerule = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "maxsizerule" ), mMaxsizerule, Rules::UnusedForceRule );
  addItem( itemMaxsizerule, QStringLiteral( "maxsizerule" ) );
  KConfigSkeleton::ItemInt  *itemOpacityactive;
  itemOpacityactive = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "opacityactive" ), mOpacityactive, 100 );
  itemOpacityactive->setMinValue(0);
  itemOpacityactive->setMaxValue(100);
  addItem( itemOpacityactive, QStringLiteral( "opacityactive" ) );
  KConfigSkeleton::ItemInt  *itemOpacityactiverule;
  itemOpacityactiverule = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "opacityactiverule" ), mOpacityactiverule, Rules::UnusedForceRule );
  addItem( itemOpacityactiverule, QStringLiteral( "opacityactiverule" ) );
  KConfigSkeleton::ItemInt  *itemOpacityinactive;
  itemOpacityinactive = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "opacityinactive" ), mOpacityinactive, 100 );
  itemOpacityinactive->setMinValue(0);
  itemOpacityinactive->setMaxValue(100);
  addItem( itemOpacityinactive, QStringLiteral( "opacityinactive" ) );
  KConfigSkeleton::ItemInt  *itemOpacityinactiverule;
  itemOpacityinactiverule = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "opacityinactiverule" ), mOpacityinactiverule, Rules::UnusedForceRule );
  addItem( itemOpacityinactiverule, QStringLiteral( "opacityinactiverule" ) );
  KConfigSkeleton::ItemBool  *itemIgnoregeometry;
  itemIgnoregeometry = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ignoregeometry" ), mIgnoregeometry, false );
  addItem( itemIgnoregeometry, QStringLiteral( "ignoregeometry" ) );
  KConfigSkeleton::ItemInt  *itemIgnoregeometryrule;
  itemIgnoregeometryrule = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "ignoregeometryrule" ), mIgnoregeometryrule, Rules::UnusedSetRule );
  itemIgnoregeometryrule->setMinValue(Rules::UnusedSetRule);
  itemIgnoregeometryrule->setMaxValue(static_cast<Rules::SetRule>(Rules::ForceTemporarily));
  addItem( itemIgnoregeometryrule, QStringLiteral( "ignoregeometryrule" ) );
  QStringList defaultdesktops;
  defaultdesktops.append( QString::fromUtf8( "{}" ) );

  KConfigSkeleton::ItemStringList  *itemDesktops;
  itemDesktops = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "desktops" ), mDesktops, defaultdesktops );
  addItem( itemDesktops, QStringLiteral( "desktops" ) );
  KConfigSkeleton::ItemInt  *itemDesktopsrule;
  itemDesktopsrule = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "desktopsrule" ), mDesktopsrule, Rules::UnusedSetRule );
  itemDesktopsrule->setMinValue(Rules::UnusedSetRule);
  itemDesktopsrule->setMaxValue(static_cast<Rules::SetRule>(Rules::ForceTemporarily));
  addItem( itemDesktopsrule, QStringLiteral( "desktopsrule" ) );
  KConfigSkeleton::ItemInt  *itemScreen;
  itemScreen = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "screen" ), mScreen, 0 );
  addItem( itemScreen, QStringLiteral( "screen" ) );
  KConfigSkeleton::ItemInt  *itemScreenrule;
  itemScreenrule = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "screenrule" ), mScreenrule, Rules::UnusedSetRule );
  itemScreenrule->setMinValue(Rules::UnusedSetRule);
  itemScreenrule->setMaxValue(static_cast<Rules::SetRule>(Rules::ForceTemporarily));
  addItem( itemScreenrule, QStringLiteral( "screenrule" ) );
  KConfigSkeleton::ItemStringList  *itemActivity;
  itemActivity = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "activity" ), mActivity );
  addItem( itemActivity, QStringLiteral( "activity" ) );
  KConfigSkeleton::ItemInt  *itemActivityrule;
  itemActivityrule = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "activityrule" ), mActivityrule, Rules::UnusedSetRule );
  itemActivityrule->setMinValue(Rules::UnusedSetRule);
  itemActivityrule->setMaxValue(static_cast<Rules::SetRule>(Rules::ForceTemporarily));
  addItem( itemActivityrule, QStringLiteral( "activityrule" ) );
  KConfigSkeleton::ItemBool  *itemMaximizevert;
  itemMaximizevert = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "maximizevert" ), mMaximizevert, false );
  addItem( itemMaximizevert, QStringLiteral( "maximizevert" ) );
  KConfigSkeleton::ItemInt  *itemMaximizevertrule;
  itemMaximizevertrule = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "maximizevertrule" ), mMaximizevertrule, Rules::UnusedSetRule );
  itemMaximizevertrule->setMinValue(Rules::UnusedSetRule);
  itemMaximizevertrule->setMaxValue(static_cast<Rules::SetRule>(Rules::ForceTemporarily));
  addItem( itemMaximizevertrule, QStringLiteral( "maximizevertrule" ) );
  KConfigSkeleton::ItemBool  *itemMaximizehoriz;
  itemMaximizehoriz = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "maximizehoriz" ), mMaximizehoriz, false );
  addItem( itemMaximizehoriz, QStringLiteral( "maximizehoriz" ) );
  KConfigSkeleton::ItemInt  *itemMaximizehorizrule;
  itemMaximizehorizrule = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "maximizehorizrule" ), mMaximizehorizrule, Rules::UnusedSetRule );
  itemMaximizehorizrule->setMinValue(Rules::UnusedSetRule);
  itemMaximizehorizrule->setMaxValue(static_cast<Rules::SetRule>(Rules::ForceTemporarily));
  addItem( itemMaximizehorizrule, QStringLiteral( "maximizehorizrule" ) );
  KConfigSkeleton::ItemBool  *itemMinimize;
  itemMinimize = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "minimize" ), mMinimize, false );
  addItem( itemMinimize, QStringLiteral( "minimize" ) );
  KConfigSkeleton::ItemInt  *itemMinimizerule;
  itemMinimizerule = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "minimizerule" ), mMinimizerule, Rules::UnusedSetRule );
  itemMinimizerule->setMinValue(Rules::UnusedSetRule);
  itemMinimizerule->setMaxValue(static_cast<Rules::SetRule>(Rules::ForceTemporarily));
  addItem( itemMinimizerule, QStringLiteral( "minimizerule" ) );
  KConfigSkeleton::ItemBool  *itemSkiptaskbar;
  itemSkiptaskbar = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "skiptaskbar" ), mSkiptaskbar, false );
  addItem( itemSkiptaskbar, QStringLiteral( "skiptaskbar" ) );
  KConfigSkeleton::ItemInt  *itemSkiptaskbarrule;
  itemSkiptaskbarrule = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "skiptaskbarrule" ), mSkiptaskbarrule, Rules::UnusedSetRule );
  itemSkiptaskbarrule->setMinValue(Rules::UnusedSetRule);
  itemSkiptaskbarrule->setMaxValue(static_cast<Rules::SetRule>(Rules::ForceTemporarily));
  addItem( itemSkiptaskbarrule, QStringLiteral( "skiptaskbarrule" ) );
  KConfigSkeleton::ItemBool  *itemSkippager;
  itemSkippager = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "skippager" ), mSkippager, false );
  addItem( itemSkippager, QStringLiteral( "skippager" ) );
  KConfigSkeleton::ItemInt  *itemSkippagerrule;
  itemSkippagerrule = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "skippagerrule" ), mSkippagerrule, Rules::UnusedSetRule );
  itemSkippagerrule->setMinValue(Rules::UnusedSetRule);
  itemSkippagerrule->setMaxValue(static_cast<Rules::SetRule>(Rules::ForceTemporarily));
  addItem( itemSkippagerrule, QStringLiteral( "skippagerrule" ) );
  KConfigSkeleton::ItemBool  *itemSkipswitcher;
  itemSkipswitcher = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "skipswitcher" ), mSkipswitcher, false );
  addItem( itemSkipswitcher, QStringLiteral( "skipswitcher" ) );
  KConfigSkeleton::ItemInt  *itemSkipswitcherrule;
  itemSkipswitcherrule = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "skipswitcherrule" ), mSkipswitcherrule, Rules::UnusedSetRule );
  itemSkipswitcherrule->setMinValue(Rules::UnusedSetRule);
  itemSkipswitcherrule->setMaxValue(static_cast<Rules::SetRule>(Rules::ForceTemporarily));
  addItem( itemSkipswitcherrule, QStringLiteral( "skipswitcherrule" ) );
  KConfigSkeleton::ItemBool  *itemAbove;
  itemAbove = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "above" ), mAbove, false );
  addItem( itemAbove, QStringLiteral( "above" ) );
  KConfigSkeleton::ItemInt  *itemAboverule;
  itemAboverule = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "aboverule" ), mAboverule, Rules::UnusedSetRule );
  itemAboverule->setMinValue(Rules::UnusedSetRule);
  itemAboverule->setMaxValue(static_cast<Rules::SetRule>(Rules::ForceTemporarily));
  addItem( itemAboverule, QStringLiteral( "aboverule" ) );
  KConfigSkeleton::ItemBool  *itemBelow;
  itemBelow = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "below" ), mBelow, false );
  addItem( itemBelow, QStringLiteral( "below" ) );
  KConfigSkeleton::ItemInt  *itemBelowrule;
  itemBelowrule = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "belowrule" ), mBelowrule, Rules::UnusedSetRule );
  itemBelowrule->setMinValue(Rules::UnusedSetRule);
  itemBelowrule->setMaxValue(static_cast<Rules::SetRule>(Rules::ForceTemporarily));
  addItem( itemBelowrule, QStringLiteral( "belowrule" ) );
  KConfigSkeleton::ItemBool  *itemFullscreen;
  itemFullscreen = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "fullscreen" ), mFullscreen, false );
  addItem( itemFullscreen, QStringLiteral( "fullscreen" ) );
  KConfigSkeleton::ItemInt  *itemFullscreenrule;
  itemFullscreenrule = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "fullscreenrule" ), mFullscreenrule, Rules::UnusedSetRule );
  itemFullscreenrule->setMinValue(Rules::UnusedSetRule);
  itemFullscreenrule->setMaxValue(static_cast<Rules::SetRule>(Rules::ForceTemporarily));
  addItem( itemFullscreenrule, QStringLiteral( "fullscreenrule" ) );
  KConfigSkeleton::ItemBool  *itemNoborder;
  itemNoborder = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "noborder" ), mNoborder, false );
  addItem( itemNoborder, QStringLiteral( "noborder" ) );
  KConfigSkeleton::ItemInt  *itemNoborderrule;
  itemNoborderrule = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "noborderrule" ), mNoborderrule, Rules::UnusedSetRule );
  itemNoborderrule->setMinValue(Rules::UnusedSetRule);
  itemNoborderrule->setMaxValue(static_cast<Rules::SetRule>(Rules::ForceTemporarily));
  addItem( itemNoborderrule, QStringLiteral( "noborderrule" ) );
  KConfigSkeleton::ItemString  *itemDecocolor;
  itemDecocolor = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "decocolor" ), mDecocolor );
  addItem( itemDecocolor, QStringLiteral( "decocolor" ) );
  KConfigSkeleton::ItemInt  *itemDecocolorrule;
  itemDecocolorrule = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "decocolorrule" ), mDecocolorrule, Rules::UnusedForceRule );
  addItem( itemDecocolorrule, QStringLiteral( "decocolorrule" ) );
  KConfigSkeleton::ItemBool  *itemBlockcompositing;
  itemBlockcompositing = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "blockcompositing" ), mBlockcompositing, false );
  addItem( itemBlockcompositing, QStringLiteral( "blockcompositing" ) );
  KConfigSkeleton::ItemInt  *itemBlockcompositingrule;
  itemBlockcompositingrule = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "blockcompositingrule" ), mBlockcompositingrule, Rules::UnusedForceRule );
  addItem( itemBlockcompositingrule, QStringLiteral( "blockcompositingrule" ) );
  KConfigSkeleton::ItemInt  *itemFsplevel;
  itemFsplevel = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "fsplevel" ), mFsplevel, 0 );
  itemFsplevel->setMinValue(0);
  itemFsplevel->setMaxValue(4);
  addItem( itemFsplevel, QStringLiteral( "fsplevel" ) );
  KConfigSkeleton::ItemInt  *itemFsplevelrule;
  itemFsplevelrule = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "fsplevelrule" ), mFsplevelrule, Rules::UnusedForceRule );
  addItem( itemFsplevelrule, QStringLiteral( "fsplevelrule" ) );
  KConfigSkeleton::ItemInt  *itemFpplevel;
  itemFpplevel = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "fpplevel" ), mFpplevel, 0 );
  itemFpplevel->setMinValue(0);
  itemFpplevel->setMaxValue(4);
  addItem( itemFpplevel, QStringLiteral( "fpplevel" ) );
  KConfigSkeleton::ItemInt  *itemFpplevelrule;
  itemFpplevelrule = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "fpplevelrule" ), mFpplevelrule, Rules::UnusedForceRule );
  addItem( itemFpplevelrule, QStringLiteral( "fpplevelrule" ) );
  KConfigSkeleton::ItemBool  *itemAcceptfocus;
  itemAcceptfocus = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "acceptfocus" ), mAcceptfocus, false );
  addItem( itemAcceptfocus, QStringLiteral( "acceptfocus" ) );
  KConfigSkeleton::ItemInt  *itemAcceptfocusrule;
  itemAcceptfocusrule = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "acceptfocusrule" ), mAcceptfocusrule, Rules::UnusedForceRule );
  addItem( itemAcceptfocusrule, QStringLiteral( "acceptfocusrule" ) );
  KConfigSkeleton::ItemBool  *itemCloseable;
  itemCloseable = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "closeable" ), mCloseable, false );
  addItem( itemCloseable, QStringLiteral( "closeable" ) );
  KConfigSkeleton::ItemInt  *itemCloseablerule;
  itemCloseablerule = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "closeablerule" ), mCloseablerule, Rules::UnusedForceRule );
  addItem( itemCloseablerule, QStringLiteral( "closeablerule" ) );
  KConfigSkeleton::ItemBool  *itemAutogroup;
  itemAutogroup = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "autogroup" ), mAutogroup, false );
  addItem( itemAutogroup, QStringLiteral( "autogroup" ) );
  KConfigSkeleton::ItemInt  *itemAutogrouprule;
  itemAutogrouprule = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "autogrouprule" ), mAutogrouprule, Rules::UnusedForceRule );
  addItem( itemAutogrouprule, QStringLiteral( "autogrouprule" ) );
  KConfigSkeleton::ItemBool  *itemAutogroupfg;
  itemAutogroupfg = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "autogroupfg" ), mAutogroupfg, true );
  addItem( itemAutogroupfg, QStringLiteral( "autogroupfg" ) );
  KConfigSkeleton::ItemInt  *itemAutogroupfgrule;
  itemAutogroupfgrule = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "autogroupfgrule" ), mAutogroupfgrule, Rules::UnusedForceRule );
  addItem( itemAutogroupfgrule, QStringLiteral( "autogroupfgrule" ) );
  KConfigSkeleton::ItemString  *itemAutogroupid;
  itemAutogroupid = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "autogroupid" ), mAutogroupid );
  addItem( itemAutogroupid, QStringLiteral( "autogroupid" ) );
  KConfigSkeleton::ItemInt  *itemAutogroupidrule;
  itemAutogroupidrule = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "autogroupidrule" ), mAutogroupidrule, Rules::UnusedForceRule );
  addItem( itemAutogroupidrule, QStringLiteral( "autogroupidrule" ) );
  KConfigSkeleton::ItemBool  *itemStrictgeometry;
  itemStrictgeometry = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "strictgeometry" ), mStrictgeometry, false );
  addItem( itemStrictgeometry, QStringLiteral( "strictgeometry" ) );
  KConfigSkeleton::ItemInt  *itemStrictgeometryrule;
  itemStrictgeometryrule = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "strictgeometryrule" ), mStrictgeometryrule, Rules::UnusedForceRule );
  addItem( itemStrictgeometryrule, QStringLiteral( "strictgeometryrule" ) );
  KConfigSkeleton::ItemString  *itemShortcut;
  itemShortcut = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "shortcut" ), mShortcut );
  addItem( itemShortcut, QStringLiteral( "shortcut" ) );
  KConfigSkeleton::ItemInt  *itemShortcutrule;
  itemShortcutrule = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "shortcutrule" ), mShortcutrule, Rules::UnusedSetRule );
  itemShortcutrule->setMinValue(Rules::UnusedSetRule);
  itemShortcutrule->setMaxValue(static_cast<Rules::SetRule>(Rules::ForceTemporarily));
  addItem( itemShortcutrule, QStringLiteral( "shortcutrule" ) );
  KConfigSkeleton::ItemBool  *itemDisableglobalshortcuts;
  itemDisableglobalshortcuts = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "disableglobalshortcuts" ), mDisableglobalshortcuts, false );
  addItem( itemDisableglobalshortcuts, QStringLiteral( "disableglobalshortcuts" ) );
  KConfigSkeleton::ItemInt  *itemDisableglobalshortcutsrule;
  itemDisableglobalshortcutsrule = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "disableglobalshortcutsrule" ), mDisableglobalshortcutsrule, Rules::UnusedForceRule );
  addItem( itemDisableglobalshortcutsrule, QStringLiteral( "disableglobalshortcutsrule" ) );
  KConfigSkeleton::ItemString  *itemDesktopfile;
  itemDesktopfile = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "desktopfile" ), mDesktopfile );
  addItem( itemDesktopfile, QStringLiteral( "desktopfile" ) );
  KConfigSkeleton::ItemInt  *itemDesktopfilerule;
  itemDesktopfilerule = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "desktopfilerule" ), mDesktopfilerule, Rules::UnusedSetRule );
  itemDesktopfilerule->setMinValue(Rules::UnusedSetRule);
  itemDesktopfilerule->setMaxValue(static_cast<Rules::SetRule>(Rules::ForceTemporarily));
  addItem( itemDesktopfilerule, QStringLiteral( "desktopfilerule" ) );
  QList<KConfigSkeleton::ItemEnum::Choice> valueslayer;
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("DesktopLayer");
    valueslayer.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("BelowLayer");
    valueslayer.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("NormalLayer");
    valueslayer.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("AboveLayer");
    valueslayer.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("NotificationLayer");
    valueslayer.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("ActiveLayer");
    valueslayer.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("PopupLayer");
    valueslayer.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("CriticalNotificationLayer");
    valueslayer.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("OnScreenDisplayLayer");
    valueslayer.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("OverlayLayer");
    valueslayer.append( choice );
  }
  KConfigSkeleton::ItemEnum  *itemLayer;
  itemLayer = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "layer" ), mLayer, valueslayer, int(NormalLayer) );
  itemLayer->setValueForChoice(QStringLiteral( "DesktopLayer" ), QStringLiteral( "desktop" ));
  itemLayer->setValueForChoice(QStringLiteral( "BelowLayer" ), QStringLiteral( "below" ));
  itemLayer->setValueForChoice(QStringLiteral( "NormalLayer" ), QStringLiteral( "normal" ));
  itemLayer->setValueForChoice(QStringLiteral( "AboveLayer" ), QStringLiteral( "above" ));
  itemLayer->setValueForChoice(QStringLiteral( "NotificationLayer" ), QStringLiteral( "notification" ));
  itemLayer->setValueForChoice(QStringLiteral( "ActiveLayer" ), QStringLiteral( "fullscreen" ));
  itemLayer->setValueForChoice(QStringLiteral( "PopupLayer" ), QStringLiteral( "popup" ));
  itemLayer->setValueForChoice(QStringLiteral( "CriticalNotificationLayer" ), QStringLiteral( "critical-notification" ));
  itemLayer->setValueForChoice(QStringLiteral( "OnScreenDisplayLayer" ), QStringLiteral( "osd" ));
  itemLayer->setValueForChoice(QStringLiteral( "OverlayLayer" ), QStringLiteral( "overlay" ));
  addItem( itemLayer, QStringLiteral( "layer" ) );
  KConfigSkeleton::ItemInt  *itemLayerrule;
  itemLayerrule = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "layerrule" ), mLayerrule, Rules::UnusedForceRule );
  addItem( itemLayerrule, QStringLiteral( "layerrule" ) );
  KConfigSkeleton::ItemBool  *itemAdaptivesync;
  itemAdaptivesync = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "adaptivesync" ), mAdaptivesync, true );
  addItem( itemAdaptivesync, QStringLiteral( "adaptivesync" ) );
  KConfigSkeleton::ItemInt  *itemAdaptivesyncrule;
  itemAdaptivesyncrule = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "adaptivesyncrule" ), mAdaptivesyncrule, Rules::UnusedForceRule );
  addItem( itemAdaptivesyncrule, QStringLiteral( "adaptivesyncrule" ) );
  KConfigSkeleton::ItemBool  *itemTearing;
  itemTearing = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "tearing" ), mTearing, true );
  addItem( itemTearing, QStringLiteral( "tearing" ) );
  KConfigSkeleton::ItemInt  *itemTearingrule;
  itemTearingrule = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "tearingrule" ), mTearingrule, Rules::UnusedForceRule );
  addItem( itemTearingrule, QStringLiteral( "tearingrule" ) );
  KConfigSkeleton::ItemBool  *itemExcludefromcapture;
  itemExcludefromcapture = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "excludefromcapture" ), mExcludefromcapture, false );
  addItem( itemExcludefromcapture, QStringLiteral( "excludefromcapture" ) );
  KConfigSkeleton::ItemInt  *itemExcludefromcapturerule;
  itemExcludefromcapturerule = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "excludefromcapturerule" ), mExcludefromcapturerule, Rules::UnusedSetRule );
  itemExcludefromcapturerule->setMinValue(Rules::UnusedSetRule);
  itemExcludefromcapturerule->setMaxValue(static_cast<Rules::SetRule>(Rules::ForceTemporarily));
  addItem( itemExcludefromcapturerule, QStringLiteral( "excludefromcapturerule" ) );
}

RuleSettings::~RuleSettings()
{
}

