// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#ifndef KWINTOUCHSCREENDATA_H
#define KWINTOUCHSCREENDATA_H

#include <QObject>

#include "kcmoduledata.h"

namespace KWin {

class KWinTouchScreenSettings;


class KWinTouchScreenData : public KCModuleData
{
    Q_OBJECT

public:
    explicit KWinTouchScreenData(QObject *parent = nullptr);
    KWinTouchScreenSettings *settings() const;


private:
    KWinTouchScreenSettings *m_settings;

};

}

#endif
