/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.KWin.NightLight.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef NIGHTLIGHTADAPTOR_H
#define NIGHTLIGHTADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "nightlightdbusinterface.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.KWin.NightLight
 */
class NightLightAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.KWin.NightLight")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.KWin.NightLight\">\n"
"    <method name=\"inhibit\">\n"
"      <arg direction=\"out\" type=\"u\" name=\"cookie\"/>\n"
"    </method>\n"
"    <method name=\"uninhibit\">\n"
"      <arg direction=\"in\" type=\"u\" name=\"cookie\"/>\n"
"    </method>\n"
"    <method name=\"preview\">\n"
"      <arg direction=\"in\" type=\"u\" name=\"temperature\"/>\n"
"    </method>\n"
"    <method name=\"stopPreview\"/>\n"
"    <property access=\"read\" type=\"b\" name=\"inhibited\"/>\n"
"    <property access=\"read\" type=\"b\" name=\"enabled\"/>\n"
"    <property access=\"read\" type=\"b\" name=\"running\"/>\n"
"    <property access=\"read\" type=\"b\" name=\"available\"/>\n"
"    <property access=\"read\" type=\"u\" name=\"currentTemperature\"/>\n"
"    <property access=\"read\" type=\"u\" name=\"targetTemperature\"/>\n"
"    <property access=\"read\" type=\"u\" name=\"mode\"/>\n"
"    <property access=\"read\" type=\"b\" name=\"daylight\"/>\n"
"    <property access=\"read\" type=\"t\" name=\"previousTransitionDateTime\"/>\n"
"    <property access=\"read\" type=\"u\" name=\"previousTransitionDuration\"/>\n"
"    <property access=\"read\" type=\"t\" name=\"scheduledTransitionDateTime\"/>\n"
"    <property access=\"read\" type=\"u\" name=\"scheduledTransitionDuration\"/>\n"
"  </interface>\n"
        "")
public:
    NightLightAdaptor(KWin::NightLightDBusInterface *parent);
    ~NightLightAdaptor() override;

    inline KWin::NightLightDBusInterface *parent() const
    { return static_cast<KWin::NightLightDBusInterface *>(QObject::parent()); }

public: // PROPERTIES
    Q_PROPERTY(bool available READ available)
    bool available() const;

    Q_PROPERTY(uint currentTemperature READ currentTemperature)
    uint currentTemperature() const;

    Q_PROPERTY(bool daylight READ daylight)
    bool daylight() const;

    Q_PROPERTY(bool enabled READ enabled)
    bool enabled() const;

    Q_PROPERTY(bool inhibited READ inhibited)
    bool inhibited() const;

    Q_PROPERTY(uint mode READ mode)
    uint mode() const;

    Q_PROPERTY(qulonglong previousTransitionDateTime READ previousTransitionDateTime)
    qulonglong previousTransitionDateTime() const;

    Q_PROPERTY(uint previousTransitionDuration READ previousTransitionDuration)
    uint previousTransitionDuration() const;

    Q_PROPERTY(bool running READ running)
    bool running() const;

    Q_PROPERTY(qulonglong scheduledTransitionDateTime READ scheduledTransitionDateTime)
    qulonglong scheduledTransitionDateTime() const;

    Q_PROPERTY(uint scheduledTransitionDuration READ scheduledTransitionDuration)
    uint scheduledTransitionDuration() const;

    Q_PROPERTY(uint targetTemperature READ targetTemperature)
    uint targetTemperature() const;

public Q_SLOTS: // METHODS
    uint inhibit();
    void preview(uint temperature);
    void stopPreview();
    void uninhibit(uint cookie);
Q_SIGNALS: // SIGNALS
};

#endif
