// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#include "kwintouchscreendata.h"

#include "kwintouchscreensettings.h"


namespace KWin {

KWinTouchScreenData::KWinTouchScreenData(QObject *parent)
: KCModuleData(parent)
, m_settings(new KWinTouchScreenSettings(this))

{
autoRegisterSkeletons();
}

KWinTouchScreenSettings *KWinTouchScreenData::settings() const
{
    return m_settings;
}



}

#include "moc_kwintouchscreendata.cpp"
