/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kwin.Effects.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "effectsadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class EffectsAdaptor
 */

EffectsAdaptor::EffectsAdaptor(KWin::EffectsHandler *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

EffectsAdaptor::~EffectsAdaptor()
{
    // destructor
}

QStringList EffectsAdaptor::activeEffects() const
{
    // get the value of property activeEffects
    return qvariant_cast< QStringList >(parent()->property("activeEffects"));
}

QStringList EffectsAdaptor::listOfEffects() const
{
    // get the value of property listOfEffects
    return qvariant_cast< QStringList >(parent()->property("listOfEffects"));
}

QStringList EffectsAdaptor::loadedEffects() const
{
    // get the value of property loadedEffects
    return qvariant_cast< QStringList >(parent()->property("loadedEffects"));
}

QList<bool> EffectsAdaptor::areEffectsSupported(const QStringList &names)
{
    // handle method call org.kde.kwin.Effects.areEffectsSupported
    return parent()->areEffectsSupported(names);
}

QString EffectsAdaptor::debug(const QString &name, const QString &name_)
{
    // handle method call org.kde.kwin.Effects.debug
    return parent()->debug(name, name_);
}

bool EffectsAdaptor::isEffectLoaded(const QString &name)
{
    // handle method call org.kde.kwin.Effects.isEffectLoaded
    return parent()->isEffectLoaded(name);
}

bool EffectsAdaptor::isEffectSupported(const QString &name)
{
    // handle method call org.kde.kwin.Effects.isEffectSupported
    return parent()->isEffectSupported(name);
}

bool EffectsAdaptor::loadEffect(const QString &name)
{
    // handle method call org.kde.kwin.Effects.loadEffect
    return parent()->loadEffect(name);
}

void EffectsAdaptor::reconfigureEffect(const QString &name)
{
    // handle method call org.kde.kwin.Effects.reconfigureEffect
    parent()->reconfigureEffect(name);
}

QString EffectsAdaptor::supportInformation(const QString &name)
{
    // handle method call org.kde.kwin.Effects.supportInformation
    return parent()->supportInformation(name);
}

void EffectsAdaptor::toggleEffect(const QString &name)
{
    // handle method call org.kde.kwin.Effects.toggleEffect
    parent()->toggleEffect(name);
}

void EffectsAdaptor::unloadEffect(const QString &name)
{
    // handle method call org.kde.kwin.Effects.unloadEffect
    parent()->unloadEffect(name);
}


#include "moc_effectsadaptor.cpp"
