// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#ifndef KWINSCREENEDGEDATA_H
#define KWINSCREENEDGEDATA_H

#include <QObject>

#include "kcmoduledata.h"

namespace KWin {

class KWinScreenEdgeSettings;


class KWinScreenEdgeData : public KCModuleData
{
    Q_OBJECT

public:
    explicit KWinScreenEdgeData(QObject *parent = nullptr);
    KWinScreenEdgeSettings *settings() const;


private:
    KWinScreenEdgeSettings *m_settings;

};

}

#endif
